package com.gic.haoban.manage.web.controller.hm;

import com.gic.api.base.commons.Page;
import com.gic.haoban.base.api.common.PageResult2;
import com.gic.haoban.base.api.common.ServiceResponse;
import com.gic.haoban.base.api.common.pojo.dto.WebLoginDTO;
import com.gic.haoban.common.utils.AuthWebRequestUtil;
import com.gic.haoban.common.utils.HaobanResponse;
import com.gic.haoban.common.utils.PageUtil;
import com.gic.haoban.manage.api.dto.hm.HmGroupDTO;
import com.gic.haoban.manage.api.dto.hm.HmGroupQueryDTO;
import com.gic.haoban.manage.api.service.hm.HmGroupApiService;
import com.gic.haoban.manage.web.controller.WebBaseController;
import com.gic.haoban.manage.web.errCode.HaoBanErrCode;
import com.gic.haoban.manage.web.qo.hm.HmGroupQO;
import com.gic.haoban.manage.web.vo.hm.HmGroupSettingVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RestController;

import javax.validation.Valid;
import java.util.ArrayList;
import java.util.List;

/**
 * @Author MUSI
 * @Date 2022/7/1 4:31 PM
 * @Description
 * @Version
 **/
@RestController
@RequestMapping(path = "/hm/group")
public class HmGroupController extends WebBaseController {

    @Autowired
    private HmGroupApiService groupApiService;

    @RequestMapping(path = "/save", method = RequestMethod.POST)
    public HaobanResponse saveHmGroupSetting(@Valid HmGroupSettingVO hmGroupSettingVO){
        WebLoginDTO loginUser = AuthWebRequestUtil.getLoginUser();
        HmGroupDTO hmGroupDTO = new HmGroupDTO();
        hmGroupDTO.setGroupName(hmGroupSettingVO.getGroupName());
        hmGroupDTO.setCreatorId(loginUser.getHanbaoUserId());
        hmGroupDTO.setCreatorName(loginUser.getClerkName());
        hmGroupDTO.setEnterpriseId(loginUser.getEnterpriseId());
        hmGroupDTO.setWxEnterpriseId(loginUser.getWxEnterpriseId());
        ServiceResponse<Long> serviceResponse = groupApiService.saveOrUpdateHmGroupSetting(hmGroupDTO);
        return resultResponse(HaoBanErrCode.ERR_1, serviceResponse.getResult());
    }

    @RequestMapping(path = "/list")
    public HaobanResponse queryHmGroupList(HmGroupQO hmGroupQo){
        WebLoginDTO loginUser = AuthWebRequestUtil.getLoginUser();
        String wxEnterpriseId = loginUser.getWxEnterpriseId();
        String enterpriseId = loginUser.getEnterpriseId();
        HmGroupQueryDTO hmGroupQueryDTO = new HmGroupQueryDTO();
        hmGroupQueryDTO.setGroupName(hmGroupQo.getGroupName());
        hmGroupQueryDTO.setPageNum(hmGroupQo.getPageNum());
        hmGroupQueryDTO.setPageSize(hmGroupQo.getPageSize());
        hmGroupQueryDTO.setWxEnterpriseId(wxEnterpriseId);
        hmGroupQueryDTO.setEnterpriseId(enterpriseId);
        ServiceResponse<Page<HmGroupDTO>> serviceResponse = groupApiService.queryHmGroupSettingList(hmGroupQueryDTO);
        PageResult2 pageInfo = PageUtil.getPageInfo(serviceResponse.getResult());
        return resultResponse(HaoBanErrCode.ERR_1, pageInfo);
    }

    @RequestMapping(path = "/edit", method = RequestMethod.POST)
    public HaobanResponse editHmGroupSetting(@Valid HmGroupSettingVO hmGroupSettingVO){
        WebLoginDTO loginUser = AuthWebRequestUtil.getLoginUser();
        HmGroupDTO hmGroupDTO = new HmGroupDTO();
        hmGroupDTO.setGroupName(hmGroupSettingVO.getGroupName());
        hmGroupDTO.setModifierId(loginUser.getClerkId());
        hmGroupDTO.setModifierName(loginUser.getClerkName());
        hmGroupDTO.setGroupId(hmGroupSettingVO.getGroupId());
        ServiceResponse<Long> serviceResponse = groupApiService.saveOrUpdateHmGroupSetting(hmGroupDTO);
        return resultResponse(HaoBanErrCode.ERR_1, serviceResponse.getResult());
    }

    @RequestMapping(path = "/delete", method = RequestMethod.POST)
    public HaobanResponse deleteHmGroupSetting(HmGroupSettingVO hmGroupSettingVO){
        if (hmGroupSettingVO.getGroupId() == null){
            return resultResponse(HaoBanErrCode.ERR_2);
        }
        WebLoginDTO loginUser = AuthWebRequestUtil.getLoginUser();
        HmGroupDTO hmGroupDTO = new HmGroupDTO();
        hmGroupDTO.setModifierId(loginUser.getClerkId());
        hmGroupDTO.setModifierName(loginUser.getClerkName());
        hmGroupDTO.setGroupId(hmGroupSettingVO.getGroupId());
        ServiceResponse<Boolean> serviceResponse = groupApiService.deleteGroupSetting(hmGroupDTO);
        return resultResponse(HaoBanErrCode.ERR_1, serviceResponse.getResult());
    }

    @RequestMapping(path = "/refer/count")
    public HaobanResponse queryGroupTotalReferCount(){
        WebLoginDTO loginUser = AuthWebRequestUtil.getLoginUser();
        ServiceResponse<Integer> serviceResponse = groupApiService.queryGroupReferCount(loginUser.getEnterpriseId(), loginUser.getWxEnterpriseId());
        return resultResponse(HaoBanErrCode.ERR_1, serviceResponse.getResult());
    }
}
